#! /bin/sh

TARGET="/mnt/mtd/ipc"
CONF="$TARGET/conf"
NETDEV=eth0
WIFIPATH="$CONF/wifi.conf"
. $WIFIPATH
NETINFO=$CONF/config_net.ini
NETPRIV=$CONF/config_priv.ini

DEF_IPADDR="192.168.0.158"
DEF_GATEWAY="192.168.0.1"

loadwifi()
{
	ifconfig $NETDEV down
	ifconfig $NETDEV up

	iwpriv $NETDEV set AuthMode=$WifiMode
	iwpriv $NETDEV set NetworkType=$WifiType
	iwpriv $NETDEV set EncrypType=$WifiEnc
	if [ $WifiEnc != "NONE" ]
	then	
		if [ $WifiEnc == "WEP" ]
		then
			iwpriv $NETDEV set DefaultKeyID=1
			iwpriv $NETDEV set Key1="$WifiKey"
		else
			iwpriv $NETDEV set WPAPSK="$WifiKey"
		fi
	fi
	iwpriv $NETDEV set SSID="$WifiSsid"
	sleep 3
	$TARGET/updatewifi.sh &
}

loadNetwork()
{	
    dhcp1=`grep dhcp $NETINFO | awk -F "\"" '{print $2}'`
    ipaddr1=`grep ipaddr $NETINFO | awk -F "\"" '{print $2}'`
    gateway1=`grep gateway $NETINFO | awk -F "\"" '{print $2}'`
    netmask1=`grep netmask $NETINFO | awk -F "\"" '{print $2}'` 

    gat1=`echo $ipaddr1 | awk -F "." '{print $1}'`
    gat2=`echo $ipaddr1 | awk -F "." '{print $2}'`
    gat3=`echo $ipaddr1 | awk -F "." '{print $3}'`
    gat4=`echo $ipaddr1 | awk -F "." '{print $4}'`
    gateway2="$gat1.$gat2.$gat3.1"     	   	
		
	if [ $dhcp1 = "y" ] 
	then
		$TARGET/dhcp.sh $NETDEV
		sleep 5
		return 0
	fi   

	if ! ifconfig $NETDEV $ipaddr1 netmask $netmask1
	then
		ifconfig $NETDEV $DEF_IPADDR netmask 255.255.255.0	
	fi
	
	if ! route add default gw $gateway1
	then
		if ! route add default gw $gateway2
		then
			route add default gw $DEF_GATEWAY
		fi
	fi
		
	return 0      
}

clearRoute()
{
	GATEWAY=`route | grep default | awk -F " " '{printf $2}'`
	route del default gw $GATEWAY
	GIP=`route | grep eth0 | awk -F " " '{printf $1}'`
	GNM=`route | grep eth0 | awk -F " " '{printf $3}'`
	route del -net $GIP netmask $GNM
}

loadAround()
{
    $TARGET/facddns.sh
    $TARGET/upnpmap.sh
    $TARGET/th3ddns.sh
    $TARGET/mdns.sh
}

killall updatewifi.sh
killall udhcpc	
killall upnpmap.sh
killall upnp_map
sleep 1
killall updatewifi.sh
killall udhcpc
killall upnpmap.sh
killall upnp_map

if [ $1 -eq 0 ]
then
	NETDEV="eth0"
	ifconfig ra0 down
	clearRoute
	mac1=`grep macaddr $CONF/config_priv.ini | awk -F "\"" '{print $2}'`
	ifconfig eth0 down
	ifconfig $NETDEV hw ether $mac1
	ifconfig eth0 up
else
	NETDEV="ra0"
	loadwifi
	clearRoute
fi

loadNetwork

killall runarp
$TARGET/runarp $NETDEV & > /dev/null

loadAround
